InteractionListener = (function(global) {
    const PLAYER_STATUS_ENDPOINT = 'http://127.0.0.1:48567/api/player/status';
    var _interactionRepository;

    InteractionListener = function(interactionRepository, events) {
        _interactionRepository = interactionRepository;
        for (var e in events) {
            if (events.hasOwnProperty(e)) {
                registerInteractionEventListener(events[e])
            }
        }
    };

    var registerInteractionEventListener = function(eventName) {
        window.addEventListener(eventName, function (e) {
            getPlayerStatus().then(function(playerStatus) {
                var interaction = {
                    payload: e.detail,
                    dateTime: new Date().toISOString(),
                    type: eventName,
                    player: playerStatus.player
                };
                _interactionRepository.add(interaction);
            });
        });
    };

    var getPlayerStatus = function() {
        return global.fetch(PLAYER_STATUS_ENDPOINT)
            .then(function(response) {
                if (response.ok) {
                    return response.json();
                }
                throw Error("Status: " + response.status);
            })
            .catch(function(error) {
                throw Error("Fetch error. " + error.message);
            });
    };

    return InteractionListener;
})(window);